@@ -2,11 +2,8 @@ from langchain.chains import LLMChain
 from prompt import CHATBOT_PROMPT
 from steamship.invocable import PackageService, get, post
 
-from steamship_langchain.llms import SteamshipGPT
-from steamship_langchain.memory import (
-    SteamshipPersistentConversationMemory,
-    SteamshipPersistentConversationWindowMemory,
-)
+from steamship_langchain.llms import OpenAI
+from steamship_langchain.memory import ConversationBufferMemory, ConversationBufferWindowMemory
 
 
 class ChatbotPackage(PackageService):
@@ -15,11 +12,11 @@ class ChatbotPackage(PackageService):
         """Returns an AI-generated response to a user conversation, based on limited prior context."""
 
         # steamship_memory will persist/retrieve conversation across API calls
-        steamship_memory = SteamshipPersistentConversationWindowMemory(
-            client=self.client, file_handle=chat_history_handle, k=2
+        steamship_memory = ConversationBufferWindowMemory(
+            client=self.client, key=chat_history_handle, k=2
         )
         chatgpt = LLMChain(
-            llm=SteamshipGPT(client=self.client, temperature=0),
+            llm=OpenAI(client=self.client, temperature=0),
             prompt=CHATBOT_PROMPT,
             memory=steamship_memory,
         )
@@ -30,8 +27,6 @@ class ChatbotPackage(PackageService):
         """Return the full transcript for a chat session."""
 
         # we can use the non-windowed memory to retrieve the full history.
-        steamship_memory = SteamshipPersistentConversationMemory(
-            client=self.client, file_handle=chat_history_handle
-        )
+        steamship_memory = ConversationBufferMemory(client=self.client, key=chat_history_handle)
 
         return steamship_memory.load_memory_variables(inputs={}).get("history", "")
