@@ -1,7 +1,7 @@
 """Provides Steamship-compatible LLMs for use in langchain (🦜️🔗) chains and agents."""
 
-from .gpt import SteamshipGPT
+from .openai import OpenAI
 
 __all__ = [
-    "SteamshipGPT",
+    "OpenAI",
 ]
